pub fn load_sessions() -> Result<Vec<Session>>
Load Codex sessions from the local Codex session store.
Returns an error when the Codex sessions directory cannot be read or a session file cannot be parsed.