pub fn load_sessions_by_key(keys: &[SessionKey]) -> Result<Vec<Session>>Expand description
Load only requested Codex sessions from the local Codex session store.
Errors
Returns an error when a matching Codex session file cannot be read or parsed.
pub fn load_sessions_by_key(keys: &[SessionKey]) -> Result<Vec<Session>>Load only requested Codex sessions from the local Codex session store.
Returns an error when a matching Codex session file cannot be read or parsed.